Lua_ClimbTowerRankWindow = class("Lua_ClimbTowerRankWindow", Lua_Window);
function Lua_ClimbTowerRankWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;	
	self.windowName = "Lua_ClimbTowerRankWindow";
	self.skinName = "ClimbTowerRankWindow_skin";
	self.isFullSizeWin = true;
	self.showBlackMask = true;
end

function Lua_ClimbTowerRankWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.bg_2:SetDimensions(720, 583 + self.adaptHeight);
	self:createBackBtn(63, 53);

    self.roleInfoPanel = Lua_RoleInfoPanel.new(self.content);
    self.roleInfoPanel:setRectAnchor(1);

	local posDic = {{0, -176}, {-250, -195}, {252.5, -195}};
	self.modelArr = Array();
	local item;
	for i = 1, 3 do
		item = Lua_ClimbTowerRankModelItem.new(self.content);
		item:setRectAnchor(1);
		item:setLocation(posDic[i][1], posDic[i][2], 0);
		item:setRank(i);
		item:setData(nil);
		self.modelArr:add(item);
	end

	self.itemList = Lua_DragList.new(self.content, 687, 550 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -160, 0);
	self.itemList:setListCell(Lua_ClimbTowerRankItem, 687, 123, 1);
	self.itemList:setCellSpacing(0, 10);

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setRectAnchor(7);
	self.avatarItem:setLocation(-155, 193, 0);

	if DataCenter.climbTowerData:checkCampTowerIsOpen() then
		self.buttonInfo = Array();
		local arr = DataCenter.climbTowerData.towerArr;
		local vo;
		for i = 1, arr:getSize() do
			vo = DataCenter.climbTowerData:getTowerVoById(arr[i]);
			self.buttonInfo:add(vo);
		end

		self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
		self.buttonList:setRectAnchor(7);
		self.buttonList.pivot = -1;
		self.buttonList:setLocation(300, 53.5, 0);
		self.buttonList:setButtonStyle("common_altas_1", "ui_common_button_001_b", "ui_common_button_001_b", 118, 108, 0.01, 1);
		self.buttonList:setButtonLine("common_altas_1", "ui_common_line_011", 2, 108, 0, 0, 1);
		self.buttonList:setButtonItem(120, 108);
		self.buttonList:setClickCallBack(self, self.onButtonClick);
		self.buttonList:setData(self.buttonInfo);
	end

	self:addLuaEvent("UPDATE_TOWER_RANK_IFNO", self, self.updateRankInfo);
end

function Lua_ClimbTowerRankWindow:dispose()
	if self.roleInfoPanel ~= nil then
		self.roleInfoPanel:dispose();
		self.roleInfoPanel = nil;
	end
	if self.modelArr ~= nil then
		self.modelArr:dispose();
		self.modelArr:clear();
		self.modelArr = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.buttonList ~= nil then
		self.buttonList:dispose();
		self.buttonList = nil;
	end
	if self.buttonInfo ~= nil then
		self.buttonInfo:clear();
		self.buttonInfo = nil;
	end
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	self:superCall("dispose");
end

function Lua_ClimbTowerRankWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.bg_2:SetDimensions(720, 583 + self.adaptHeight);
	self.itemList:setContentRect(687, 550 + self.adaptHeight);
end

function Lua_ClimbTowerRankWindow:showWin(param)
	self:superCall("showWin", param);
	if self.buttonList == nil then
		local arr = DataCenter.climbTowerData.towerArr;
		local vo = DataCenter.climbTowerData:getTowerVoById(arr[param]);
		self.towerName.text = vo.name;
		Lua_ProxyManager.getProxy("Lua_ClimbTowerProxy"):sTowerRank(arr[param]);
	else
		self.buttonList:setSelected(param);
	end
end

function Lua_ClimbTowerRankWindow:onButtonClick(index)
	local vo = self.buttonInfo[index];
	self.towerName.text = vo.name;
	Lua_ProxyManager.getProxy("Lua_ClimbTowerProxy"):sTowerRank(vo.id);
end

function Lua_ClimbTowerRankWindow:updateRankInfo(msg)
	if msg == nil then
		return;
	end

	local list = msg.rank_list;
	table.sort( list, function(a, b) return a.rank < b.rank end);
	local len = #list;
	for i = 1, 3 do
		if len >= i then
			self.modelArr[i]:setData(msg.rank_list[i]);
		else
			self.modelArr[i]:setData(nil);
		end
	end

	len = 3;
	while len > 0 do
		table.remove(list, 1);
		len = len - 1;
	end

	self:showNone(#list <= 0);
	self.itemList:setArrayData(list);
	self.itemList:moveToIndex(1, true);

	self:updateSelf(msg.self_rank);
end

function Lua_ClimbTowerRankWindow:updateSelf(data)
	if data == nil then
		return;
	end

	if data.rank <= 0 then
		self.rankIcon:setEnable(true);
		if self.rankNum ~= nil then
			self.rankNum:setEnable(false);
		end
	else
		self.rankIcon:setEnable(false);
		if self.rankNum == nil then
			self.rankNum = Lua_NumberImage.new(self.content);
			self.rankNum:setRectAnchor(7);
			self.rankNum:setLocation(-280, 189, 0);
			self.rankNum.numOffsetX = -4;
			self.rankNum.numAtlas = "number";
			self.rankNum.preStr = "ui_djc2_title_0";
		end
		self.rankNum:setEnable(true);
		self.rankNum.num = data.rank;
	end

	self.avatarItem:setRoleId(data.player_show.id);
	self.avatarItem:setRoleDressUp(data.player_show.dress_info);
	self.avatarItem:setRoleLevel(data.player_show.level);

	self.nameText.text = data.player_show.name;
	self.valueText.text = data.value;
end

function Lua_ClimbTowerRankWindow:showNone(bShow)
	if bShow then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "ui_liaotian_widget_002", 0, -156, 648, 119);
		end
		self.noneIcon:setEnable(true);

		if self.noneText == nil then
			self.noneText = UICreate.createLabel(self.content, LanUtil.getValue(201023), 0, -156, 100, 40, 34);
			self.noneText.pivot = UIUtils.Pivot.Center;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("EBEBEB");
		end
		self.noneText:setEnable(true);
	else
		if self.noneIcon ~= nil then
			self.noneIcon:setEnable(false);
		end
		if self.noneText ~= nil then
			self.noneText:setEnable(false);
		end
	end
end




















Lua_ClimbTowerRankModelItem = class("Lua_ClimbTowerRankModelItem", Lua_DisplayObject);
function Lua_ClimbTowerRankModelItem:ctor(p)
	self:superCall("ctor", p, "ClimbTowerRankModelItem_skin");
end

function Lua_ClimbTowerRankModelItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_ClimbTowerRankModelItem:dispose()
	if self.modelEffImg then
		self.modelEffImg:dispose()
		self.modelEffImg = nil
	end
	self.data = nil
	self:superCall("dispose");
end

function Lua_ClimbTowerRankModelItem:setRank(rank)
	self.rank = rank
	self.rankIcon:setAltas("common_altas_3", "ui_djc_label_0"..rank);
	if rank == 1 then
		self.rankIcon:setLocation(-81, -70, 0);
		self.valueBg:setLocation(0, -300, 0);
		self.valueText:setLocation(3.5, -300, 0);
	elseif rank == 2 then
		self.rankIcon:setLocation(-79.5, -75, 0);
		self.valueBg:setLocation(2, -302, 0);
		self.valueText:setLocation(2, -302, 0);
	else
		self.rankIcon:setLocation(-71, -73, 0);
		self.valueBg:setLocation(-8, -292, 0);
		self.valueText:setLocation(-8, -292, 0);
	end
end

function Lua_ClimbTowerRankModelItem:setData(data)
	self.data = data
	if data == nil then
		self.nameText:setLangValue(201002);
		self.valueText.text = "";
		if self.modelEffImg then
			self.modelEffImg:setEnable(false)
		end
	else
		self.nameText.text = data.player_show.name;
		self.valueText.text = data.value;
		if self.modelEffImg == nil then
			local str = Lua_CommonUtil.getModelName(rank)
			self.modelEffImg = UICreate.createModelEffImg(self.content, "/model/"..str, str, 0, -120, 0, 0)
			self.modelEffImg.siblingIndex = 0
			self.modelEffImg:setCamField(1, 1, 100, true)
			self.modelEffImg:setCamPos(0, 1, -10)
			self.modelEffImg:setModelEffDir(180)
			self.modelEffImg.canRot = false
			self.modelEffImg.clickScale = false
			self.modelEffImg:addClickFuntion(self, self.onModelClick)
		end
		self.modelEffImg:setEnable(true)
		self.modelEffImg:setScale(0.35, 0.35, 0.35)
	end
end

function Lua_ClimbTowerRankModelItem:onModelClick(go)
	if self.data == nil then
		return;
	end

	if DataCenter.roleData:isMyself(self.data.player_show.id) then
		OperateAlert.showLangValue(171025);
	else
		Lua_WindowUtil.openWin("Lua_PlayerInfoWindow", Lua_WinParam.ACTION_OPEN, self.data.player_show.id);
	end	
end






















Lua_ClimbTowerRankItem = class("Lua_ClimbTowerRankItem", Lua_ListCell);
function Lua_ClimbTowerRankItem:ctor(p)
	self:superCall("ctor", p, "ClimbTowerRankItem_skin");
end

function Lua_ClimbTowerRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setLocation(-280, 0, 0);
	self.rankNum.numOffsetX = -4;
	self.rankNum.numAtlas = "number";
	self.rankNum.preStr = "ui_djc_title_0";

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-155, 0, 0);
end

function Lua_ClimbTowerRankItem:dispose()
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self:superCall("dispose");
end

function Lua_ClimbTowerRankItem:setData(data)
	if data == nil then
		return;
	end

	self.avatarItem:setRoleId(data.player_show.id);
	self.avatarItem:setRoleDressUp(data.player_show.dress_info);
	self.avatarItem:setRoleLevel(data.player_show.level);

	self.rankNum.num = data.rank;
	self.nameText.text = data.player_show.name;
	-- if data.player_show.league_id == nil or tonumber(data.player_show.league_id) <= 0 then
	-- 	self.allianceText.text = LanUtil.formateStr(201014, LanUtil.getValue(201015));
	-- else
	-- 	self.allianceText.text = LanUtil.formateStr(201014, data.player_show.league_name);
	-- end
	self.valueText.text = data.value;
end