Lua_ClimbTowerWindow = class("Lua_ClimbTowerWindow", Lua_Window);
function Lua_ClimbTowerWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;	
	self.windowName = "Lua_ClimbTowerWindow";
	self.skinName = "ClimbTowerWindow_skin";
	self.isFullSizeWin = true;
	self.showWinBg = true;
	self.winBgPath = "/images/climb_tower/ui_ttt_bj_002.jpg";
	self.showBackBtn = true;
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/images/climb_tower/ui_ttt_ta_02.png", Lua_LoadFileType.IMG);
	self:addPreLoadRes("/images/climb_tower/ui_ttt_ta_03.png", Lua_LoadFileType.IMG);
end

function Lua_ClimbTowerWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.dailyIcon:setEnable(false);

	self.itemList = Lua_DragList.new(self.content, 720, 1400 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList.movementTypeValue = 2;
	self.itemList:setLocation(0, -20, 0);
	self.itemList:setSiblingIndex(1);
	self.itemList:setListCell(Lua_ClimbTowerItem, 720, 373, 1);
	self.itemList:setCellSpacing(0, -30);

	self.rankArr = Array();
	local item;
	for i = 1, 3 do
		item = Lua_ClimbTowerRankMiniItem.new(self.rankObject);
		item:setLocation(-216, -123 - (i - 1) * 42, 0);
		item:setData(i);
		self.rankArr:add(item);
	end

	self.redPoint_Clearance = Lua_RedPointIcon.new(self.content, Lua_RedPointList.ClimbTower_Clearance);
	self.redPoint_Clearance:setRectAnchor(7);
	self.redPoint_Clearance:setLocation(315, 310, 0);

	self:addLuaEvent("UPDATE_TOWER_INFO", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_TOWER_RANK_IFNO", self, self.updateRankInfo);
	self:addLuaEvent("TOWER_REWARD_RECEIVE", self, self.onRewardReceive);
	self:addLuaEvent("TOWER_CHECK_DETAILS", self, self.onCheckDetails);

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.checkRank:addClickFuntion(self, self.onCheckRank);
	self.rewardBg:addClickFuntion(self, self.onCheckReward);
	self.dailyIcon:addClickFuntion(self, self.onCheckDailyReward);
	self.btnChallenge:addClickFuntion(self, self.onBtnChallengeClick);
end

function Lua_ClimbTowerWindow:dispose()
	DataCenter.preLoadData:removeBySign("Lua_TowerLineupWindow", self, self.onSceneShow);
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.rankArr ~= nil then
		self.rankArr:dispose();
		self.rankArr:clear();
		self.rankArr = nil;
	end
	if self.redPoint_Clearance ~= nil then
		self.redPoint_Clearance:dispose();
		self.redPoint_Clearance = nil;
	end
	if self.redPoint_Daily ~= nil then
		self.redPoint_Daily:dispose();
		self.redPoint_Daily = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ClimbTowerWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.itemList:setContentRect(720, 1400 + self.adaptHeight);
end

function Lua_ClimbTowerWindow:showWin(param)
	self:superCall("showWin",param)
	if type(param) == "table" then
		self.towerId = param.main_id;
	elseif type(param) == "number" then
		self.towerId = param;
	end

	self.data = DataCenter.climbTowerData:getTowerVoById(self.towerId);
	if self.data.bInitServer then
		self:updateShowInfo();
	else
		Lua_ProxyManager.getProxy("Lua_ClimbTowerProxy"):sTowerInfo(self.towerId);
	end
	Lua_ProxyManager.getProxy("Lua_ClimbTowerProxy"):sTowerRank(self.towerId);
end

function Lua_ClimbTowerWindow:updateShowInfo()
	if self.data == nil then
		self.data = DataCenter.climbTowerData:getTowerVoById(self.towerId);
	end
	self.titleText.text = self.data.name;

	local arr = DataCenter.climbTowerUtil:getTowerInfoById(self.towerId);
	local len = arr:getSize();
	local cur_stage_storey = self.data.cur_stage_storey;
	local index;
	if cur_stage_storey > 1 then
		index = len - cur_stage_storey + 2; -- 1：到底 3：居中
	else
		index = len;
	end
	self.itemList:setArrayData(arr);
	self.itemList:moveToIndex(index, true, true);

	local des, tvo = DataCenter.climbTowerUtil:getRewardInfo(self.towerId);
	if tvo == nil then
		self.rewardObject:SetActive(false);
	else
		self.rewardObject:SetActive(true);
		self.rewardIcon:setAltas(tvo.atlas, tvo.sprite);
		self.rewardText.text = des;
	end

	self.dailyIcon:setEnable(self.towerId == Lua_ClimbTowerUtil.LIGHT_ID);
	if self.towerId == Lua_ClimbTowerUtil.LIGHT_ID and self.redPoint_Daily == nil then
		self.redPoint_Daily = Lua_RedPointIcon.new(self.content, Lua_RedPointList.ClimbTower_9_Daily);
		self.redPoint_Daily:setRectAnchor(7);
		self.redPoint_Daily:setLocation(315, 200, 0);
	end
end

function Lua_ClimbTowerWindow:updateRankInfo(msg)
	if msg == nil then
		return;
	end

	table.sort( msg.rank_list, function(a, b) return a.rank < b.rank end);
	local len = #msg.rank_list;
	for i = 1, 3 do
		if len >= i then
			self.rankArr[i]:setData(i, msg.rank_list[i]);
		else
			self.rankArr[i]:setData(i, nil);
		end
	end
end

function Lua_ClimbTowerWindow:onBackBtnClick(go)
	self:superCall("onBackBtnClick", go);
	if DataCenter.climbTowerData:checkCampTowerIsOpen() then
		DataCenter.funcPathUtil:gotoFunction(1010);
	end
end

function Lua_ClimbTowerWindow:onRewardReceive(stageId)
	Lua_ProxyManager.getProxy("Lua_ClimbTowerProxy"):sReceiveTowerReward(self.towerId, stageId);
end

function Lua_ClimbTowerWindow:onCheckDetails(stageId)
	Lua_WindowUtil.openWin("Lua_ClimbTowerDetailsWindow", Lua_WinParam.ACTION_OPEN, stageId);
end

function Lua_ClimbTowerWindow:onCheckHelp(go)
	local tipsData = { des = self.data.rule, posX = 213, posY = -170 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ClimbTowerWindow:onCheckRank(go)
	Lua_WindowUtil.openWin("Lua_ClimbTowerRankWindow", Lua_WinParam.ACTION_OPEN, self.data.sort);
end

function Lua_ClimbTowerWindow:onCheckReward(go)
	Lua_WindowUtil.openWin("Lua_ClimbTowerRewardWindow", Lua_WinParam.ACTION_OPEN, self.data.sort);
end

function Lua_ClimbTowerWindow:onCheckDailyReward(go)
	Lua_WindowUtil.openWin("Lua_ClimbTowerDailyRewardWindow", Lua_WinParam.ACTION_OPEN, self.towerId);
end

function Lua_ClimbTowerWindow:onBtnChallengeClick(go)
	if self.data.isLimit == true then
		OperateAlert.showLangValue(201001);
		return;
	end

	if self.data.cur_stage_state == 1 then
		OperateAlert.showLangValue(201021);
		return;
	end

	local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(self.data.fight_id);
	DataCenter.preLoadData:preShowScene("Lua_TowerLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, nil, sceneId, 0);
end

function Lua_ClimbTowerWindow:onSceneShow(param)
	Lua_WindowUtil.openWin("Lua_TowerLineupWindow", Lua_WinParam.ACTION_OPEN, self.data);
end





















Lua_ClimbTowerItem = class("Lua_ClimbTowerItem", Lua_ListCell);
function Lua_ClimbTowerItem:ctor(p)
	self:superCall("ctor", p, "ClimbTowerItem_skin");
end

function Lua_ClimbTowerItem:buildShowItem()
	self:superCall("buildShowItem");
	self.checkDetails:addClickFuntion(self, self.onCheckDetails);
end

function Lua_ClimbTowerItem:dispose()
	if self.modelEffImg ~= nil then
		self.modelEffImg:dispose();
		self.modelEffImg = nil;
	end
	if self.extraItem ~= nil then
		self.extraItem:dispose();
		self.extraItem = nil;
	end
	self:superCall("dispose");
end

function Lua_ClimbTowerItem:setData(id)
	self.id = id;

	local config = DataCenter.climbTowerUtil:getTowerConfig(id);
	self.layerText.text = config.storey;

	local vo = DataCenter.climbTowerData:getTowerVoById(config.index);
	if vo.cur_stage_state == 1 or config.storey < vo.cur_stage_storey then -- 已通关
		self.doorMask:setEnable(false);
		self.checkDetails:setEnable(true);
		self.completedIcon:setEnable(true);
		self:setSelected(false);
		self:showModel(nil);
	else
		self.completedIcon:setEnable(false);
		if config.storey == vo.cur_stage_storey then
			self.doorMask:setEnable(false);
			self.checkDetails:setEnable(true);
			self:setSelected(true);
			self:showModel(config.robot);
		else
			self.doorMask:setEnable(true);
			self.checkDetails:setEnable(false);
			self:setSelected(false);
			self:showModel(nil);
		end
	end

	config = DataCenter.climbTowerUtil:getRewardConfig(id);
	self.rewardState = vo.pass_list == nil and 0 or vo.pass_list[id];
	if config == nil or self.rewardState == 2 then
		self.bg:setUrl("/images/climb_tower/ui_ttt_ta_02.png")
		self.layerText:setLocation(0,96, 0)
		self.checkDetails:setLocation(54, 96, 0)
		self:setReward(nil);
	else
		self.bg:setUrl("/images/climb_tower/ui_ttt_ta_03.png")
		self.layerText:setLocation(0, 86, 0)
		self.checkDetails:setLocation(54, 86, 0)
		self:setReward(config.reward);
	end
end

function Lua_ClimbTowerItem:setSelected(bSelected)
	if bSelected then
		if self.selectedImg == nil then
			self.selectedImg = UICreate.createImage(self.content, "/images/climb_tower/ui_ttt_ta_04.png", 4, 0, 720, 431);
			self.selectedImg.siblingIndex = 0
		end
		self.selectedImg:setEnable(true);
	else
		if self.selectedImg ~= nil then
			self.selectedImg:setEnable(false);
		end
	end
end

function Lua_ClimbTowerItem:showModel(monsterId)
	if monsterId == nil then
		if self.modelEffImg ~= nil then
			self.modelEffImg:setEnable(false);
		end
	else
		local monsterConfig = Lua_MonsterPlayerConfigData.getConfigData(monsterId);
		monsterId = monsterConfig.fighter_list[1][1][1];
		monsterConfig = Lua_MonsterConfigData.getMonsterConfig(monsterId);
		local modelSrc = monsterConfig.heroVo.modelSrc;
		if self.modelEffImg == nil then
			self.modelEffImg = UICreate.createModelEffImg(self.content, nil, nil, 0, -50, 161, 161);
			self.modelEffImg:setCamField(1, 1, 100, true);
			self.modelEffImg:setCamPos(0, 1, -10);
			self.modelEffImg:setModelEffDir(180);
			self.modelEffImg.canRot = false;
		end
		self.modelEffImg:setEnable(true);
		self.modelEffImg:setUrl("/model/"..modelSrc, modelSrc);
	end
end

function Lua_ClimbTowerItem:setReward(reward)
	if reward == nil then
		self.rewardBg:setEnable(false);
		if self.extraItem ~= nil then
			self.extraItem:setEnable(false);
		end
	else
		self.rewardBg:setEnable(true);
		if self.extraItem == nil then
			self.extraItem = Lua_ItemIcon.new(self.content);
			self.extraItem:setLocation(-174.5, -6, 0);
			self.extraItem:setScale(0.8, 0.8, 0.8)
			self.extraItem:setClick(self, self.onItemClick);
		end
		self.extraItem:setEnable(true);
		local tvo = Lua_ToolVo.createToolVo(reward[1][1], reward[1][2]);
		self.extraItem:setData(tvo);
		self.extraItem:showRedPoint(self.rewardState == 1);
	end
end

function Lua_ClimbTowerItem:onItemClick(data)
	if self.rewardState == 1 then
		Lua_MsgUtil.callFunc("TOWER_REWARD_RECEIVE", self.id);
	else
		DataCenter.packUtil:showItemInfo(data);
	end
end

function Lua_ClimbTowerItem:onCheckDetails(go)
	Lua_MsgUtil.callFunc("TOWER_CHECK_DETAILS", self.id);
end






















Lua_ClimbTowerRankMiniItem = class("Lua_ClimbTowerRankMiniItem", Lua_ListCell);
function Lua_ClimbTowerRankMiniItem:ctor(p)
	self:superCall("ctor", p, "ClimbTowerRankMiniItem_skin");
end

function Lua_ClimbTowerRankMiniItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_ClimbTowerRankMiniItem:dispose()
	self:superCall("dispose");
end

function Lua_ClimbTowerRankMiniItem:setData(rank, data)
	self.rankIcon:setAltas("climb_tower_atlas_1", "ui_ttt_title_0"..rank);
	self.rankIcon:resetSize();
	if data == nil then
		self.nameText:setLangValue(201002);
		self.layerText.text = "";
	else
		self.nameText.text = Lua_ColorDefine.getColorStr("FFED9A", data.player_show.name);
		self.layerText.text = LanUtil.formateStr(201000, tostring(data.value));
	end
end